@@ -3,21 +3,23 @@
 mkdir build
 cd build
 
-#ls $SP_DIR/numpy/core/include
 export BUILD_NUMPY_INCLUDE_DIRS=$( $PYTHON -c "import numpy; print (numpy.get_include())")
 export TARGET_NUMPY_INCLUDE_DIRS=$SP_DIR/numpy/core/include
 
 echo $BUILD_NUMPY_INCLUDE_DIRS
 echo $TARGET_NUMPY_INCLUDE_DIRS
 
+export GENERATE_PYTHON_STUBS=1
 if [[ $CONDA_BUILD_CROSS_COMPILATION == 1 ]]; then
   mkdir -p $TARGET_NUMPY_INCLUDE_DIRS
   cp -r $BUILD_NUMPY_INCLUDE_DIRS/numpy $TARGET_NUMPY_INCLUDE_DIRS
+  export GENERATE_PYTHON_STUBS=0
 fi
 
 cmake ${CMAKE_ARGS} .. \
       -DCMAKE_BUILD_TYPE=Release \
       -DPYTHON_EXECUTABLE=$PYTHON \
+      -DGENERATE_PYTHON_STUBS=$GENERATE_PYTHON_STUBS \
       -DNUMPY_INCLUDE_DIRS=$TARGET_NUMPY_INCLUDE_DIRS
 make
 make install
